\author{Tom Minka}
\name{area.map}
\alias{area.map}
\title{
  Area of projected map regions
}
\usage{
area.map(m, regions = ".", sqmi=TRUE, ...)
}
\description{Computes the areas of regions in a projected map.}
\arguments{
  \item{m}{a map object containing named polygons (created with
  \code{fill = TRUE}).}
  \item{regions}{a character vector naming one of more regions, as in
    \code{\link{map}}.}
  \item{sqmi}{If \code{TRUE}, measure area in square miles.  Otherwise
    keep the units of \code{m}.}
  \item{...}{additional arguments to \code{\link{match.map}}}
}
\details{
  The area of each matching region in the map is computed, and
  regions which match the same element of \code{regions} have their
  areas combined.  Each region is assumed planar, with vertices
  specified by the \code{x} and \code{y} components of the map object.

  The correct use of this function is to first use \code{\link{map}} to
  create polygons and project the coordinates onto a plane, then apply
  \code{area.map} to compute the area of the projected regions.
  If the projection is area-preserving (such as \code{albers}),
  then these areas will match the area on the globe, up to a
  constant.  To get an absolute area in square miles, the \code{sqmi}
  option will scale the result, depending on the projection.

  The coordinates from \code{\link{map}} are affected by 
  its \code{resolution} argument, so use \code{resolution=0} for the most
  accurate areas.
}
\section{NOTE}{
  The \code{sqmi} option assumes the coordinates have been projected
  with the \link[mapproj]{mapproject} function.
}
\value{
  a named vector of region areas.
}
\seealso{\code{area.polygon}, \code{apply.polygon}}
\examples{
# because the projection is rectangular, these are not true areas on the globe.
m = map("state", fill = TRUE, plot = FALSE)
area.map(m)
area.map(m, ".*dakota")
area.map(m, c("North Dakota", "South Dakota"))

if(require(mapproj)) {
  # true areas on the globe
  m = map("state", proj="bonne", param=45, fill=TRUE, plot=FALSE)
  # North Dakota is listed as 70,704 square miles
  area.map(m, "North Dakota")
}
}
\keyword{dplot}

\eof
\name{county}
\docType{data}
\alias{county}
\alias{countyMapEnv}
\title{
United States County Map
}
\usage{data(countyMapEnv)
}
\description{

This database produces a map of the counties of the United States mainland
generated from US Department of the Census data (see the reference).
}
\format{
The data file is merely an assignment to a character string which
specifies the name of an environment variable which contains the
base location of the binary files used by the map drawing functions.
This environment variable (\code{R_MAP_DATA_DIR} for the datasets in the
maps package) is set at package load time \emph{if it does not
already exist}.  Hence setting the environment variable before loading
the package can override the default location of the binary datasets.
}
\seealso{
\code{\link{map}}.
}
\examples{
map('county', 'iowa', fill = TRUE, col = palette())
}
\references{
Richard A. Becker, and Allan R. Wilks,
"Maps in S",
\emph{AT\&T Bell Laboratories Statistics Research Report [93.2], 1993.}

Richard A. Becker, and Allan R. Wilks,
"Constructing a Geographical Database",
\emph{AT\&T Bell Laboratories Statistics Research Report [95.2], 1995.}

US Department of Commerce, Census Bureau,
\emph{County Boundary File,}
computer tape, available from Customer Services,
Bureau of the Census, Washingdon DC 20233.
}
\keyword{datasets}

\eof
\name{france}
\docType{data}
\alias{france}
\alias{franceMapEnv}
\title{
France Map
}
\usage{data(franceMapEnv)}
\description{
This france database comes from the NUTS III (Tertiary Administrative
Units of the European Community) database of the United Nations
Environment Programme (UNEP) GRID-Geneva data sets. These were prepared
around 1989, and so may be somewhat out of date.

Users of data sets supplied through UNEP/GRID are requested to
incorporate in output products and reports acknowledgements to the
originator of the data and to the fact that they were acquired through
UNEP/GRID. Appropriate wording may be "UNESCO (1987) through
UNEP/GRID-Geneva". 
}
\format{
The data file is merely an assignment to a character string which
specifies the name of an environment variable which contains the
base location of the binary files used by the map drawing functions.
This environment variable (\code{R_MAP_DATA_DIR} for the datasets in the
maps package) is set at package load time \emph{if it does not
already exist}. Hence setting the environment variable before loading
the package can override the default location of the binary datasets.
}
\source{
http://www.grid.unep.ch/data/grid/gnv159.php
}.
}
\seealso{
\code{\link{map}}
}
\examples{
map('france', fill = TRUE, col = 1:10)
}
\references{
Richard A. Becker, and Allan R. Wilks,
"Maps in S",
\emph{AT\&T Bell Laboratories Statistics Research Report [93.2], 1993.}

Richard A. Becker, and Allan R. Wilks,
"Constructing a Geographical Database",
\emph{AT\&T Bell Laboratories Statistics Research Report [95.2], 1995.}
}
\keyword{datasets}

\eof
\author{Tom Minka}
\name{identify.map}
\alias{identify.map}
\title{
  Identify regions on a map
}
\description{
  Identifies the map regions clicked by the user.
}
\usage{
identify.map(x, n = 1, index = FALSE, ...)
}
\arguments{
  \item{x}{a map object containing named polygons.}
  \item{n}{the number of clicks to wait for.}
  \item{index}{If TRUE, returns the index of the polygon, rather than
    its name.}
  \item{...}{additional arguments passed to \code{\link{identify.default}}.}
}
\details{
  The current algorithm is somewhat crude --- selects the region whose
  centroid is closest to the click.  A more sophisticated approach would
  use \code{\link{map.where}}.
}
\value{
  a character vector of length \code{n}, naming the selected regions.
}
\seealso{\code{\link{identify}}, \code{\link{map.where}}}
\examples{
identify(map("state", fill = TRUE, col = 0))
if(require(mapproj))
  identify(map("world", proj = "lagrange", fill = TRUE, col = 0))
}
\keyword{iplot}

\eof
\name{internal}
\alias{internal}
\alias{makepoly}
\alias{mapgetg}
\alias{mapgetl}
\alias{mapname}
\alias{mapthin}
\alias{maptype}
\title{Internally Required Functions}

\usage{
makepoly(xy, gonsize, keep)
mapgetg(database, gons, fill, xlim, ylim)
mapgetl(database, lines, xlim, ylim, fill)
mapname(database, patterns, exact)
mapthin(xy, delta, symmetric)
maptype(database)
}

\description{
These functions are called internally and will generally not be
required by the user.
}

\keyword{internal}

\eof
\name{internal2}
\alias{internal2}
\alias{char.to.ascii}
\alias{is.regexp}
\alias{indicators.factor}
\alias{insert}
\alias{match.map.slow}
\alias{match.map.grep}
\alias{map.old}
\alias{map.poly}
\alias{map.wrap}
\alias{subgroup}
\alias{gp.smooth}
\alias{kernel.smooth}
\alias{kernel.region.region}
\alias{kernel.region.x}
\title{Internally Required Functions}

\usage{
char.to.ascii(s)
is.regexp(s)
indicators.factor(y)
insert(x, i, v)
match.map.slow(nam, regions, warn = FALSE)
match.map.grep(nam, regions, warn = FALSE)
map.old(database = "state", regions = ".", exact = F, boundary = T, 
    interior = T, fill = F, projection = "", parameters = NULL, 
    orientation = rep(NA, 3), color = 1, add = F, plot = T, namesonly = F, 
    xlim = c(-1e+30, 1e+30), ylim = c(-1e+30, 1e+30), resolution = 1, 
    type = "l", ...) 
map.poly(database, regions = ".", exact = FALSE, xlim = NULL, ylim = NULL,
         boundary = TRUE, interior = TRUE, fill = FALSE, as.polygon = FALSE)
map.wrap(p)
subgroup(x, i)
gp.smooth(x, z, xo, lambda, r)
kernel.smooth(x, z, xo, lambda, region = NULL, normalize = TRUE)
kernel.region.region(x, region, lambda)
kernel.region.x(x, region, z, lambda)
}

\description{
These functions are called internally and will generally not be
required by the user.
}

\keyword{internal}

\eof
\name{italy}
\docType{data}
\alias{italy}
\alias{italyMapEnv}
\title{
Italy Map
}
\usage{data(italyMapEnv)}
\description{
This italy database comes from the NUTS III (Tertiary Administrative
Units of the European Community) database of the United Nations
Environment Programme (UNEP) GRID-Geneva data sets. These were prepared
around 1989, and so may be somewhat out of date.

Users of data sets supplied through UNEP/GRID are requested to
incorporate in output products and reports acknowledgements to the
originator of the data and to the fact that they were acquired through
UNEP/GRID. Appropriate wording may be "UNESCO (1987) through
UNEP/GRID-Geneva". 
}
\format{
The data file is merely an assignment to a character string which
specifies the name of an environment variable which contains the
base location of the binary files used by the map drawing functions.
This environment variable (\code{R_MAP_DATA_DIR} for the datasets in the
maps package) is set at package load time \emph{if it does not
already exist}. Hence setting the environment variable before loading
the package can override the default location of the binary datasets.
}
\source{
http://www.grid.unep.ch/data/grid/gnv159.php
}.
}
\seealso{
\code{\link{map}}
}
\examples{
map('italy', fill = TRUE, col = 1:10)
}
\references{
Richard A. Becker, and Allan R. Wilks,
"Maps in S",
\emph{AT\&T Bell Laboratories Statistics Research Report [93.2], 1993.}

Richard A. Becker, and Allan R. Wilks,
"Constructing a Geographical Database",
\emph{AT\&T Bell Laboratories Statistics Research Report [95.2], 1995.}
}
\keyword{datasets}

\eof
\name{map}
\alias{map}
\title{
  Draw Geographical Maps
}
\description{Draw lines and polygons as specified by a map database.}
\synopsis{
map(database = "world", regions = ".", exact = FALSE, boundary = TRUE,
  interior = TRUE, projection = "", parameters = NULL, orientation = NULL,
  fill = FALSE, col = 1, plot = TRUE, add = FALSE, namesonly = FALSE,
  xlim = NULL, ylim = NULL, wrap = FALSE, resolution = if(plot) 1 else 0,
  type = "l", bg = par("bg"), mar = c(0, 0, par("mar")[3], 0.1),
  border = 0.01, ...)
}
\usage{
map(database, regions)  # simple form
map(database = "world", regions = ".", exact = FALSE, boundary = TRUE,
  interior = TRUE, projection = "", parameters = NULL, orientation = NULL,
  fill = FALSE, col = 1, plot = TRUE, add = FALSE, namesonly = FALSE,
  xlim = NULL, ylim = NULL, wrap = FALSE, resolution = if(plot) 1 else 0,
  type = "l", bg = par("bg"), mar = c(0, 0, par("mar")[3], 0.1),
  border = 0.01, ...)
}
\arguments{
  \item{database}{
    character string naming a geographical database, or a list of
    \code{x}, \code{y}, and \code{names} obtained from a previous call to
    \code{map}.
    The string choices include a \code{\link{world}} map,
    three USA databases (\code{\link{usa}}, \code{\link{state}},
    \code{\link{county}}), and more (see the package index).  The
    location of the map databases may be overridden by setting the
    \code{R_MAP_DATA_DIR} environment variable.  See \code{\link{world}}
    for further details.
  }
  \item{regions}{
    character vector that names the polygons to draw.
    Each database is composed of a collection of polygons, and each polygon has
    a unique name.
    When a region is composed of more than one polygon, the individual polygons
    have the name of the region, followed by a colon and a qualifier,
    as in \code{michigan:north} and \code{michigan:south}.
    Each element of \code{regions} is matched
    against the polygon names in the database and, according to
    \code{exact}, a subset is selected for drawing.
    The default selects all polygons in the database.
  }
  \item{exact}{
    If \code{TRUE}, only exact matches with \code{regions} are
    selected for drawing.
    If \code{FALSE}, each element of \code{regions} is matched
    as a regular expression
    against the polygon names in the database and all matches are selected
    for drawing.
  }
  \item{boundary}{
    If \code{FALSE}, boundary segments are not drawn.
    A boundary segment is a line segment of the map that bounds only
    one of the polygons to be drawn.
    This argument is ignored if \code{fill} is \code{TRUE}.
  }
  \item{interior}{
    If \code{FALSE}, interior segments are not drawn.
    An interior segment is a line segment of the map that bounds two
    of the polygons to be drawn.
    This argument is ignored if \code{fill} is \code{TRUE}.
  }
  \item{projection}{
    character string that names a map projection to use.
    See \code{\link[mapproj]{mapproject}} (in the \code{mapproj} library).
    The default is to use a rectangular projection with the aspect ratio
    chosen so that longitude and latitude scales are equivalent at the
    center of the picture.
  }
  \item{parameters}{
    numeric vector of parameters for use with the
    \code{projection} argument.
    This argument is optional only in the sense that certain
    projections do not require additional parameters.
    If a projection does require additional parameters, these
    must be given in the \code{parameters} argument.
  }
  \item{orientation}{
    a vector \code{c(latitude, longitude, rotation)} describing where
    the map should be centered and a clockwise rotation (in degrees)
    about this center.
  }
  \item{fill}{
    logical flag that says whether to draw lines or fill areas.
    If \code{FALSE}, the lines bounding each region will be drawn (but
    only once, for interior lines).
    If \code{TRUE}, each region will be filled using colors from the
    \code{col =} argument, and bounding lines will not be drawn.
  }
  \item{col}{
    vector of colors.
    If \code{fill} is \code{FALSE}, the first color is used for plotting
    all lines, and any other colors are ignored.
    Otherwise, the colors are matched one-one with the polygons
    that get selected by the \code{region} argument (and are reused
    cyclically, if necessary).
    A color of \code{NA} causes the corresponding region to be deleted
    from the list of polygons to be drawn.
    Polygon colors are assigned \emph{after} polygons are deleted due to values
    of the \code{xlim} and \code{ylim} arguments.
  }
  \item{plot}{
    logical flag that specifies whether plotting
    should be done.
    If \code{plot} is \code{TRUE} the return value of \code{map} will
    not be printed automatically .
  }
  \item{add}{
    logical flag that specifies whether to add to the
    current plot.
    If \code{FALSE}, a new plot is begun, and a new coordinate
    system is set up.
  }
  \item{namesonly}{
    If \code{TRUE}, the return value will be a character vector of
    the names of the selected polygons.  See the Value section below.
  }
  \item{xlim}{
    two element numeric
    vector giving a range of longitudes, expressed
    in degreees, to which drawing
    should be restricted.
    Longitude is measured in degrees east of Greenwich, so that, in particular,
    locations in the USA have negative longitude.
    If \code{fill = TRUE}, polygons selected by \code{region} must be entirely inside
    the \code{xlim} range.
    The default value of this argument spans the entire longitude range
    of the \code{database}.
  }
  \item{ylim}{
    two element 
    numeric vector giving a range of latitudes,
    expressed in degrees, to which drawing
    should be restricted.
    Latitude is measured in degrees north of the
    equator, so that, in particular,
    locations in the USA have positive latitude.
    If \code{fill = TRUE}, polygons selected by \code{region} must be entirely inside
    the \code{ylim} range.
    The default value of this argument spans the entire latitude range
    of the \code{database}.
  }
  \item{wrap}{If TRUE, lines that cross too far across the map
    (due to a strange projection) are omitted.}
  \item{resolution}{
    number that specifies the resolution with which
    to draw the map.
    Resolution 0 is the full resolution of the database.
    Otherwise, just before polylines are plotted they are thinned:
    roughly speaking, successive points on the polyline that are
    within \code{resolution} device pixels of one another are collapsed
    to a single point (see the Reference for further details).
  }
  \item{type}{
    character string that controls drawing of the map.
    Aside from the default \code{type = "l"}, the value \code{type = "n"}
    can be used
    to set up the coordinate system and projection for a map that will
    be added to in later calls.
  }
  \item{bg}{
    background color.
  }
  \item{mar}{
    margins, as in \code{\link{par}}.
  }
  \item{border}{
    scalar or vector of length 2 specifying the porportion of the plot
    to add to the defined or computed limits as borders.
  }
  \item{...}{Extra arguments passed to \code{polygon} or \code{lines}.}
}
\value{
  If \code{plot = TRUE}, a plot is made where 
  the polygons selected from \code{database}, through the
  \code{regions}, \code{xlim}, and \code{ylim} arguments, are outlined
  (\code{fill} is \code{FALSE}) or filled (\code{fill} is \code{TRUE})
  with the colors in \code{col}.  

  The return value is a list with
  \code{x}, \code{y}, \code{range}, and \code{names} components.  
  This object can be used as a \code{database} for successive calls
  to \code{map} and functions.
  If \code{fill} is \code{FALSE}, the \code{x} and \code{y} vectors are
  the coordinates of successive polylines, separated by \code{NA}s.  If
  \code{fill} is \code{TRUE}, the \code{x} and \code{y} vectors have
  coordinates of successive polygons, again separated by \code{NA}s.
  Thus the return value can be handed directly to \code{lines} or
  \code{polygon}, as appropriate.

  When \code{namesonly} is \code{TRUE}, only the names component is returned.

  After a call to \code{map} for which the \code{projection} argument was
  specified there will be a global variable \code{.Last.projection}
  containing information about the projection used.
  This will be consulted in subsequent calls to \code{map} which use
  \code{projection = ''}.
}
\examples{
map()	# low resolution map of the world
map('usa')	# national boundaries
map('county', 'new jersey')	# county map of New Jersey
map('state', region = c('new york', 'new jersey', 'penn'))	# map of three states
map("state", ".*dakota", border = 0)	# map of the dakotas
map.axes()				# show the effect of border = 0
if(require(mapproj))
  map('state', proj = 'bonne', param = 45)	# Bonne equal-area projection of states

# names of the San Juan islands in Washington state
map('county', 'washington,san', names = TRUE, plot = FALSE)

# national boundaries in one linetype, states in another
# (figure 5 in the reference)
map("state", interior = FALSE)
map("state", boundary = FALSE, lty = 2, add = TRUE)

# plot the ozone data on a base map
# (figure 4 in the reference)
data(ozone)
map("state", xlim = range(ozone$x), ylim = range(ozone$y))
text(ozone$x, ozone$y, ozone$median)
box()
}
\seealso{
  \code{\link{map.text}}, \code{\link{map.axes}},
  \code{\link{map.scale}}, \code{\link[mapproj]{map.grid}} (in the \code{mapproj} library)
}
\references{
  Richard A. Becker, and Allan R. Wilks,
  "Maps in S",
  \emph{AT\&T Bell Laboratories Statistics Research Report [93.2], 1993.}
  \url{http://www.research.att.com/areas/stat/doc/93.2.ps}

  Richard A. Becker, and Allan R. Wilks,
  "Constructing a Geographical Database",
  \emph{AT\&T Bell Laboratories Statistics Research Report [95.2], 1995.}
  \url{http://www.research.att.com/areas/stat/doc/95.2.ps}
}
\keyword{hplot}
% Converted by Sd2Rd version 0.3-3.

\eof
\name{map.axes}
\alias{map.axes}
\title{
  Draw Axes on Geographical Maps
}
\description{Draws a set of axes on an existing map.}
\usage{
map.axes()
}
\section{Side Effects}{
x- and y-axes are drawn for the currently displayed map.  These will
display in longitude and latitude (if no projection= has been
specified in the map() call).
}
\details{
}
\examples{
map("state")
map.axes()
}
\keyword{hplot}


\eof
\name{map.cities}
\alias{map.cities}
\title{
Add Cities to Existing Map
}
\usage{
map.cities(x = world.cities, country = "", label = NULL, minpop = 0,
maxpop = Inf, capitals = 0, cex = par("cex"), \dots)
}
\description{
  Adds city locations and (optionally) names to an existing map using a
  specified database.
}
\section{NOTE}{
  This function is available only if no projection= has been
  specified in the map() call.
}
\arguments{
\item{x}{
Name of database. See \code{\link{world.cities}} to determine the structure of
the database.
}
\item{country}{
If the string country is specified, limit the displayed cities to be
from within the specified country.
}
\item{label}{
If \code{TRUE}, label all cities.  If \code{NULL},
the cities will be labelled unless there are 20 or more.
}
\item{minpop}{
The minimum value of population below which a particular city will not
be shown.
}
\item{maxpop}{
The maximum value of population above which a particular city will not
be shown.
}
\item{capitals}{
Selection of capitals-only display. Capitals may be 1 (country capital),
2 (provincial, state, or regional capital) or 3 (local capital). See
\code{\link{world.cities}} for further information.
}
\item{cex}{
The value of cex acts to override the current value of character size
expansion.
}
\item{...}{
Further plotting parameters may be specified as for the commands
\code{\link{points}} and \code{\link{text}}.
}}
\value{
No value is returned from map.cities.
}
\section{Side Effects}{
All cities within the boundaries of the plot containing the current map
are added to the plot.  Note that it is possible that the boundaries of
the plot exceed the boundaries of the map requested, and so more cities
than were expected might be shown.
}
\details{
The database is searched for all cities matching the specified criteria
and fitting within the limits of the plot currently displayed.  The
default database is of all cities that have a population greater than
100,000 or which are capital cities of a country or island territory.
The data are from around 1980-1990.
}
\seealso{
\code{\link{world.cities}}
}
\examples{
map("world", "China")
map.cities(country = "China", capitals = 2)
}
\keyword{hplot}

\eof
\name{map.scale}
\alias{map.scale}
\title{
Add Scale to Existing Unprojected Map
}
\description{
Adds a scale to an existing map, both as a ratio and a distance gauge.
}
\section{NOTE}{
  This function is meaningful only if no projection= has been specified
  in the call to map().
}
\usage{
map.scale(x, y, relwidth = 0.15, metric = TRUE, ratio = TRUE, \dots)
}
\arguments{
\item{x}{
}
\item{y}{
Location of left end of distance gauge.  If not specified, this will be
taken to be near the lower left corner of the map.
}
\item{relwidth}{
Proportion of width of display to be used for the scale.  The default is
0.15 (15\%).
}
\item{metric}{
  If \code{TRUE}, the distance gauge will be in km, otherwise miles.
}
\item{ratio}{
  If \code{FALSE}, the scale ratio of the map is not displayed.
}
\item{...}{
Further plotting parameters may be specified as for the command text().
}}
\value{
The exact calculated scale is returned.
}
\section{Side Effects}{
A scale is added to the currently displayed map. This takes the form of
an approximate 1:n scale (containing 2-3 significant digits), above a
distance gauge which is reasonably accurate for the latitude at which it
appears.  The circumference at the given latitude is interpolated from a
radius of 6356.78 km at the pole and 6378.16 km at the equator.
}
\details{
The scale is calculated from the displayed graph's plotting parameters,
and the latitude of the location at which the distance gauge will be
displayed.
}
\seealso{
\code{\link{map.axes}}
}
\examples{
map("world", "China")
map.scale()
}
\keyword{hplot}

\eof
\author{Tom Minka}
\name{map.text}
\alias{map.text}
\title{
  Draw a map with labeled regions
}
\description{
  Like \code{\link{map}}, but labels the regions.
}
\usage{
map.text(database, regions = ".", labels, cex = 0.75, add = FALSE,
move = FALSE, ...)
}
\arguments{
  \item{database}{character string naming a geographical database, or a list of
    \code{x}, \code{y}, and \code{names} obtained from a previous call to
    \code{map}.}
  \item{regions}{character vector that names the polygons to draw.}
  \item{labels}{character vector of labels, one for each region.
    Defaults to the names in the database.}
  \item{cex}{character expansion factor.}
  \item{add}{If \code{FALSE}, a map is drawn, then labels placed on top.  If
    \code{TRUE}, labels are added to the existing map.}
  \item{move}{If \code{TRUE}, labels are moved so that they don't
    overlap.  Requires the \code{mining} library.}
  \item{...}{Other arguments are the same as in \code{\link{map}}.}
}
\value{
  If \code{add = FALSE}, a map is drawn by calling \code{\link{map}}.
  Then the label for each region is placed at the centroid of the region
  polygon.

  The return value is a map object, as from \code{\link{map}}.
}
\examples{
map.text("world", "ira")    # iran and iraq
map.text("state", "penn")
map.text("county", "penn")  # Pennsylvania counties
map.text("county", "new jersey")  # New Jersey counties
}
\keyword{hplot}

\eof
\author{Tom Minka}
\name{map.where}
\alias{map.where}
\title{
  Locate points on a map
}
\description{
  Returns the region names containing given locations.
}
\usage{
map.where(database = "world", x, y)
}
\arguments{
  \item{database}{character string naming a geographical database, or a list of
    \code{x}, \code{y}, and \code{names}.
    See the documentation for \link{map} for more details.}
  \item{x}{vector of longitudes.}
  \item{y}{vector of latitudes.}
}
\value{
  A list of character strings, naming the map region that each
  (longitude, latitude) pair falls into.
}
\seealso{\code{in.polygon}}
\note{
  Because maps are currently organized as flat files, this function can be
  slow.
}
\examples{
# NYC
map.where("state", -73.8, 41)
# Auckland
map.where("nz", 174.6, -36.92)
# find both in the world (takes a while)
map.where(x = c(174.6, -73.8), y = c(-36.92, 41))
# with a map object:
m = map("state", "new york", fill = TRUE, plot = FALSE)
map.where(m, -73.8, 41)
}
\keyword{iplot}

\eof
\author{Tom Minka}
\name{match.map}
\alias{match.map}
\title{
Index map regions
}
\description{
Assigns an index to each map region, useful for map coloring.
}
\usage{
match.map(database, regions, exact = FALSE, warn = TRUE)
}
\arguments{
  \item{database}{
    character string naming a geographical database, or a map object.
    See the documentation for \code{\link{map}} for more details.
  }
  \item{regions}{
    a vector of names, or more generally regular expressions
    to match against the map region names.
  }
  \item{exact}{If \code{TRUE}, only exact matches with \code{regions}
    are considered.  Otherwise each element of \code{regions} is assumed
    to be a regular expression.
    Matches are always case-insensitive.}
  \item{warn}{If \code{TRUE}, a warning is printed when an element of
    \code{regions} matches nothing in the map.}
}
\value{
  Returns an integer vector giving an index to each region in the database.
  The index is the index of the string in \code{regions} which matches the
  region name.  Matching is done as in \code{\link{map}}.
  More specifically, all regions \code{r} whose name matches 
  \code{regions[i]} will have index \code{i}.
  Unmatched regions will have index \code{NA}.
  Overlapping matches cause an error.

  This behavior differs from \code{\link{pmatch}} because a single entry
  in \code{regions} may match several entries in the map.
}
\seealso{\code{\link{grep}}}
\examples{
# filled map showing Republican vote in 1900
# (figure 6 in the reference)
data(state, package = "base")
data(votes.repub)
state.to.map <- match.map("state", state.name)
x <- votes.repub[state.to.map, "1900"]
gray.colors <- function(n) gray(rev(0:(n - 1))/n)
color <- gray.colors(100)[floor(x)]
map("state", fill = TRUE, col = color); map("state", add = TRUE)
}
\references{
Richard A. Becker, and Allan R. Wilks,
"Maps in S",
\emph{AT\&T Bell Laboratories Statistics Research Report, 1991.}
\url{http://www.research.att.com/areas/stat/doc/93.2.ps}
}
\keyword{dplot}

\eof
\name{nz}
\docType{data}
\alias{nz}
\alias{nzMapEnv}
\title{
New Zealand Basic Map
}
\usage{data(nzMapEnv)}
\description{
This database produce a map of New Zealand at a basic level of
detail.  The `"nz"' database includes the 3 main Islands and 19 smaller
coastal islands.
}
\format{
The data file is merely an assignment to a character string which
specifies the name of an environment variable which contains the
base location of the binary files used by the map drawing functions.
This environment variable (\code{R_MAP_DATA_DIR} for the datasets in the
maps package) is set at package load time \emph{if it does not
already exist}.  Hence setting the environment variable before loading
the package can override the default location of the binary datasets.
}
\seealso{
\code{\link{map}}
}
\examples{
map('nz')
map('nz', xlim = c(166, 179), ylim = c(-48, -34))
}
\references{
Richard A. Becker, and Allan R. Wilks,
"Maps in S",
\emph{AT\&T Bell Laboratories Statistics Research Report [93.2], 1993.}

Richard A. Becker, and Allan R. Wilks,
"Constructing a Geographical Database",
\emph{AT\&T Bell Laboratories Statistics Research Report [95.2], 1995.}
}
\keyword{datasets}

\eof
\name{ozone}
\docType{data}
\alias{ozone}
\alias{votes.repub}
\title{Sample datasets}
\usage{
data(ozone)
data(votes.repub)
}
\description{Datasets used to illustrate map functions.}
\keyword{datasets}

\eof
\name{polygon}
\alias{apply.polygon}
\alias{area.polygon}
\alias{centroid.polygon}
\alias{as.matrix.polygon}
\alias{closed.polygon}
\alias{in.polygon}
\alias{in.one.polygon}
\alias{range.polygon}
\alias{num.polygons}
\alias{sub.polygon}
\title{Polygon functions}
\usage{
area.polygon(p)
centroid.polygon(p)
as.matrix.polygon(x)
closed.polygon(p)
in.one.polygon(p, x)
in.polygon(p, x)
num.polygons(p)
range.polygon(..., na.rm = FALSE)
sub.polygon(p, i)
}
\description{
These functions are called internally and will generally not be
required by the user.
}
\keyword{internal}

\eof
\author{Tom Minka}
\name{smooth.map}
\alias{smooth.map}
\title{
  Smooth out aggregated data
}
\description{
  Increases the resolution of data aggregated over map regions,
  by either smoothing or interpolation.
  Also fills in missing values.
}
\usage{
smooth.map(m, z, res = 50, span = 1/10, averages = FALSE, type = c("smooth",
"interp"), merge = FALSE)
}
\arguments{
  \item{m}{a map object}
  \item{z}{a named vector}
  \item{res}{a vector of length two, specifying the resolution of the
    sampling grid in
    each dimension.  If a single number, it is taken as the vertical
    resolution, with double taken as the horizontal resolution.}
  \item{span}{kernel parameter (larger = smoother).
    \code{span = Inf} is a special case which invokes the cubic spline kernel.
    \code{span} is automatically scaled by the map size, and is
    independent of \code{res}.}
  \item{averages}{If \code{TRUE}, the values in \code{z} are interpreted
    as averages over the regions.  Otherwise they are interpreted as totals.}
  \item{type}{see details.}
  \item{merge}{If \code{TRUE}, a region named in \code{z} includes
    all matching regions in the map (according to
    \code{\link{match.map}}).
    If \code{FALSE}, a region named in
    \code{z} is assumed to refer to exactly one region on the map.}
}
\details{
  For \code{type = "smooth"}, the region totals are first converted
  into point measurements on the
  sampling grid, by dividing the total for a region among all sample
  points inside it.  Then it is a regular kernel smoothing 
  problem.  Note that the region totals are not preserved.
  
  The prediction \eqn{z_o}{zo} for
  location \eqn{x_o}{xo} (a vector) is the average of \code{z} for
  nearby sample points:
  
  \deqn{z_o = \frac{\sum_x k(x, x_o) z(x)}{\sum_x k(x, x_o)}}{%
    zo = (sum_x k(x, xo) z(x))/(sum_x k(x, xo))}
  \deqn{k(x, x_o) = exp(-\lambda ||x - x_o||^2)}{%
    k(x, xo) = exp(-lambda ||x - xo||^2)}
  \eqn{\lambda}{lambda} is determined from \code{span}.
  Note that \eqn{x_o}{xo} is over the same sampling grid as
  \eqn{x}{x}, but \eqn{z_o}{zo} is not necessarily the same as
  \eqn{z(x_o)}{z(xo)}.
  
  For \code{type = "interp"}, the region totals are preserved by the
  higher-resolution function.
  The function is assumed to come from a
  Gaussian process with kernel \eqn{k}{k}.  The measurement \code{z[r]}
  is assumed to be the sum of the function over the discrete sample
  points inside region \code{r}.
  This leads to a simple formula for the covariance matrix of \code{z}
  and the cross-covariance between \code{zo} and \code{z}.
  The prediction is the cross-covariance times the inverse covariance
  times \code{z}.  Unlike Tobler's method, the predictions are not
  constrained to live within the original data range,
  so there tends to be "ringing" effects.

  See the references for more details.
}
\value{
  A data frame with columns \code{x}, \code{y}, and \code{z}
  giving the smoothed value \code{z} for locations (x, y).
  Currently the (x, y) values form a grid, but this is not
  guaranteed in the future.
}
\references{
  W.F. Eddy and A. Mockus. 
  An example of the estimation and display of a smoothly varying
  function of time and space - the incidence of mumps disease.
  \emph{Journal of the American Society for Information Science},
  45(9):686-693, 1994.
  \url{http://www.research.avayalabs.com/user/audris/papers/jasis.pdf}
  
  W. R. Tobler.  Smooth pycnophylactic interpolation for
  geographical regions.  \emph{Journal of the American Statistical
  Association} 74:519-530, 1979.
}
\examples{
# compare to the example for match.map
data(state, package = "base")
data(votes.repub)
z = votes.repub[, "1900"]
m = map("state", fill = TRUE, plot = FALSE)
# use a small span to fill in, but not smooth, the data
# increase the resolution to get better results
fit = smooth.map(m, z, span = 1/100, merge = TRUE, ave = TRUE)
mat = tapply(fit$z, fit[1:2], mean)
gray.colors <- function(n) gray(rev(0:(n - 1))/n)
par(bg = "blue")
filled.contour(mat, color.palette = gray.colors, nlev = 32, asp = 1)
# another way to visualize:
image(mat, col = gray.colors(100))

# for a higher degree of smoothing:
# fit = smooth.map(m, z, merge = TRUE, ave = TRUE)
# interpolation, state averages are preserved:
# fit = smooth.map(m, z, merge = TRUE, ave = TRUE, type = "interp")
}
\keyword{dplot}

\eof
\name{state}
\docType{data}
\alias{state}
\alias{stateMapEnv}
\title{
United States State Boundaries Map
}
\usage{data(stateMapEnv)}
\description{

This database produces a map of the states of the United States mainland
generated from US Department of the Census data (see the reference).
}
\format{
The data file is merely an assignment to a character string which
specifies the name of an environment variable which contains the
base location of the binary files used by the map drawing functions.
This environment variable (\code{R_MAP_DATA_DIR} for the datasets in the
maps package) is set at package load time \emph{if it does not
already exist}.  Hence setting the environment variable before loading
the package can override the default location of the binary datasets.
}
\seealso{
\code{\link{map}}.
}
\examples{
map('state', fill = TRUE, col = palette())
}
\references{
Richard A. Becker, and Allan R. Wilks,
"Maps in S",
\emph{AT\&T Bell Laboratories Statistics Research Report [93.2], 1993.}

Richard A. Becker, and Allan R. Wilks,
"Constructing a Geographical Database",
\emph{AT\&T Bell Laboratories Statistics Research Report [95.2], 1995.}

US Department of Commerce, Census Bureau,
\emph{County Boundary File,}
computer tape, available from Customer Services,
Bureau of the Census, Washingdon DC 20233.
}
\keyword{datasets}

\eof
\name{usa}
\docType{data}
\alias{usa}
\alias{usaMapEnv}
\title{
United States Coast Map
}
\usage{data(usaMapEnv)}
\description{

This database produces a map of the United States mainland generated from
US Department of the Census data (see the reference).
}
\format{
The data file is merely an assignment to a character string which
specifies the name of an environment variable which contains the
base location of the binary files used by the map drawing functions.
This environment variable (\code{R_MAP_DATA_DIR} for the datasets in the
maps package) is set at package load time \emph{if it does not
already exist}.  Hence setting the environment variable before loading
the package can override the default location of the binary datasets.
}
\seealso{
\code{\link{map}}.
}
\examples{
map('usa')
}
\references{
Richard A. Becker, and Allan R. Wilks,
"Maps in S",
\emph{AT\&T Bell Laboratories Statistics Research Report [93.2], 1993.}

Richard A. Becker, and Allan R. Wilks,
"Constructing a Geographical Database",
\emph{AT\&T Bell Laboratories Statistics Research Report [95.2], 1995.}

US Department of Commerce, Census Bureau,
\emph{County Boundary File,}
computer tape, available from Customer Services,
Bureau of the Census, Washingdon DC 20233.
}
\keyword{datasets}

\eof
\name{world}
\docType{data}
\alias{world}
\alias{worldMapEnv}
\title{
Low resolution World Map
}
\usage{data(worldMapEnv)}
\description{

This world database comes from a thinned cleaned-up version of the CIA
World Data Bank II data and contains approximately 30,000 points
representing the world coastlines and national boundaries.  The full
database of nearly 2 million points is found in the mapdata package.

}
\format{
The data file is merely an assignment to a character string which
specifies the name of an environment variable which contains the
base location of the binary files used by the map drawing functions.
This environment variable (\code{R_MAP_DATA_DIR} for the datasets in the
maps package) is set at package load time \emph{if it does not
already exist}.  Hence setting the environment variable before loading
the package can override the default location of the binary datasets.
}
\source{
The CIA World Data Bank II is currently (mid-2003) available from 
\url{http://www.evl.uic.edu/pape/data/WDB/}.
}
\seealso{
\code{\link{map}}
}
\examples{
map('world', fill = TRUE, col = 1:10)
}
\references{
Richard A. Becker, and Allan R. Wilks,
"Maps in S",
\emph{AT\&T Bell Laboratories Statistics Research Report [93.2], 1993.}

Richard A. Becker, and Allan R. Wilks,
"Constructing a Geographical Database",
\emph{AT\&T Bell Laboratories Statistics Research Report [95.2], 1995.}
}
\keyword{datasets}

\eof
\name{world.cities}
\docType{data}
\alias{world.cities}
\title{
Database of world cities
}
\usage{data{world.cities}}

\description{
This database is primarily of world cities of population greater than
100,000.  Also included are capital cities of any population size, and
some local additions.
}
\format{
A list with 6 components, namely "name", "country.etc", "lat", "long",
"pop",  and "capital", containing the city name (in uppercase for
capital cities), the country name, latitude, longitude, approximate
population, and capital status indication (0 for non-capital, 1 for
capital, 2 for China Municipalities, and 3 for China Provincial
capitals)
}
\section{NOTE}{
Some of the country names and city names are out of date.  Please send
any corrections to the package maintainer.
}
\seealso{
\code{\link{map.cities}}
}
\keyword{datasets}

\eof
\name{world2}
\docType{data}
\alias{world2}
\alias{world2MapEnv}
\title{
Pacific Centric Low resolution World Map
}
\usage{data(world2MapEnv)}
\description{

This world database comes from a thinned cleaned-up version of the CIA
World Data Bank II data and contains approximately 30,000 points
representing the world coastlines and national boundaries.  The full
database of nearly 2 million points is found in the mapdata package.
This map is based on latitudes [0, 360), which then has the Pacific
Ocean in the centre of the map.

}
\format{
The data file is merely an assignment to a character string which
specifies the name of an environment variable which contains the
base location of the binary files used by the map drawing functions.
This environment variable (\code{R_MAP_DATA_DIR} for the datasets in the
maps package) is set at package load time \emph{if it does not
already exist}.  Hence setting the environment variable before loading
the package can override the default location of the binary datasets.
}
\source{
The CIA World Data Bank II is currently (mid-2003) available from 
\url{http://www.evl.uic.edu/pape/data/WDB/}.
}
\seealso{
\code{\link{map}}, \code{\link{world}}
}
\examples{
map('world2', xlim = c(100, 300))
map.axes()
}
\references{
Richard A. Becker, and Allan R. Wilks,
"Maps in S",
\emph{AT\&T Bell Laboratories Statistics Research Report [93.2], 1993.}

Richard A. Becker, and Allan R. Wilks,
"Constructing a Geographical Database",
\emph{AT\&T Bell Laboratories Statistics Research Report [95.2], 1995.}
}
\keyword{datasets}

\eof
